@@ -4,33 +4,34 @@ data_location = os.path.join(__dir__, "data")
 src = "https://github.com/picolibc/picolibc"
 
 # Module version
-version_str = "1.7.7.post146"
-version_tuple = (1, 7, 7, 146)
+version_str = "1.7.8.post473"
+version_tuple = (1, 7, 8, 473)
 try:
     from packaging.version import Version as V
-    pversion = V("1.7.7.post146")
+    pversion = V("1.7.8.post473")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "1.7.7.post4"
-data_version_tuple = (1, 7, 7, 4)
+data_version_str = "1.7.8.post331"
+data_version_tuple = (1, 7, 8, 331)
 try:
     from packaging.version import Version as V
-    pdata_version = V("1.7.7.post4")
+    pdata_version = V("1.7.8.post331")
 except ImportError:
     pass
-data_git_hash = "579710373351530f3614389cbb1dc1f3f2085b56"
-data_git_describe = "1.7.7-4-g579710373"
+data_git_hash = "5c5f2a2e2a46066fafae38d228e1550339578fd0"
+data_git_describe = "1.7.8-331-g5c5f2a2e2"
 data_git_msg = """\
-commit 579710373351530f3614389cbb1dc1f3f2085b56
-Author: Max Behensky <maxb@twinlanes.com>
-Date:   Thu Jun 2 16:49:04 2022 -0700
+commit 5c5f2a2e2a46066fafae38d228e1550339578fd0
+Author: Keith Packard <keithp@keithp.com>
+Date:   Wed Sep 14 15:35:19 2022 +0100
 
-    Fix issues with out of source build CMake install.
+    .github: Build MSP430 bits
     
-    The picolibc.specs file lives in the build directory, not the source directory.
-    The picolibc.h file wasn't getting copied to the install include directory.
+    Use the TI MSP430 GNU SDK to build using both clang and gcc.
+    
+    Signed-off-by: Keith Packard <keithp@keithp.com>
 
 """
 
