@@ -161,7 +161,9 @@ No supporting OS subroutines are required.
 int __EXPORT __mb_cur_max = 6;
 #endif
 
-NEWLIB_THREAD_LOCAL_LOCALE struct __locale_t *_locale = &__global_locale;
+#ifdef _MB_CAPABLE
+NEWLIB_THREAD_LOCAL struct __locale_t *_locale = &__global_locale;
+#endif
 
 char *_PathLocale = NULL;
 
@@ -430,7 +432,7 @@ setlocale (
 
 #ifdef _MB_CAPABLE
 static char *
-currentlocale ()
+currentlocale (void)
 {
   int i;
 
